@@ -689,7 +689,7 @@ void Rainbow::HubClient::set_allocated_size (Resource *r, size_t s)
 {
 	total_allocated_size -= r->allocated_size / 1024;
 	r->allocated_size = s;
-	total_allocated_size += r->allocated_size * 1024;
+	total_allocated_size += r->allocated_size / 1024;
 
 	if (s != 0)
 		review_cache_size();
